#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-instances
version:              1.0.5
visibility:           public
id:                   binary-instances-1.0.5-12BeU4oqEpW9aHMOs7BtNJ
key:                  binary-instances-1.0.5-12BeU4oqEpW9aHMOs7BtNJ
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskellari/binary-instances#readme
synopsis:             Orphan instances for binary
description:
    `binary-instances` defines orphan instances for types in some popular packages.

category:             Web
abi:                  077f1c7911459de56784dbda21483792
exposed:              True
exposed-modules:
    Data.Binary.Instances Data.Binary.Instances.Aeson
    Data.Binary.Instances.CaseInsensitive
    Data.Binary.Instances.Hashable Data.Binary.Instances.Primitive
    Data.Binary.Instances.Scientific Data.Binary.Instances.Tagged
    Data.Binary.Instances.Text Data.Binary.Instances.Time
    Data.Binary.Instances.UnorderedContainers
    Data.Binary.Instances.Vector

import-dirs:          /usr/lib/ghc-9.6.6/site-local/binary-instances-1.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/binary-instances-1.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/binary-instances-1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-instances
hs-libraries:         HSbinary-instances-1.0.5-12BeU4oqEpW9aHMOs7BtNJ
depends:
    aeson-2.2.2.0-Kh0pDn2f78S4mLhsXsZzzT base-4.18.2.1 binary-0.8.9.1
    binary-orphans-1.0.5.1-JNFEePsplA5FiWrNbleM0W
    case-insensitive-1.2.1.0-2w7xRwFPLfwFgOPFogdG9O
    hashable-1.4.7.0-AuDVFqXH7XaG9xiVOVTNBi
    primitive-0.9.1.0-6CfKGfsdmQ2DJp0H0kqumj
    scientific-0.3.8.1-5DbHtB8w5OO3mo7GyLG4Aa
    tagged-0.8.10-9VJfLOM9ch68xR35ePL46j text-2.0.2
    time-compat-1.9.9-G65z3WIalBkGWfJMe5JaxM
    unordered-containers-0.2.20.1-IS42DvcTPVH3F2RDVwits
    vector-0.13.2.0-1mI63yzxbUH28Wn11C5uSI
    vector-binary-instances-0.2.5.2-3OYE7DuINb9HEMbsaY1EGF

haddock-interfaces:
    /usr/share/doc/haskell-binary-instances/html/binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-binary-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

